@@ -44,91 +44,100 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../configdialog.ui" line="322"/>
+        <location filename="../configdialog.ui" line="300"/>
+        <source>Exclude capital letters</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../configdialog.ui" line="317"/>
+        <source>Generate easy to memorize but less secure passwords</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../configdialog.ui" line="324"/>
+        <source>Exclude numbers</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../configdialog.ui" line="343"/>
         <source>Git:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../configdialog.ui" line="380"/>
+        <location filename="../configdialog.ui" line="405"/>
         <source>System:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../configdialog.ui" line="418"/>
+        <location filename="../configdialog.ui" line="450"/>
         <source>Programs</source>
         <translation>程序</translation>
     </message>
     <message>
-        <location filename="../configdialog.ui" line="436"/>
+        <location filename="../configdialog.ui" line="468"/>
         <source>Select password storage program:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../configdialog.ui" line="445"/>
-        <source>&amp;Native git/gpg</source>
-        <translation>本地应用 git/gpg</translation>
+        <location filename="../configdialog.ui" line="789"/>
+        <source>&lt;a href=&quot;https://QtPass.org/&quot;&gt;QtPass&lt;/a&gt; version </source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../configdialog.ui" line="452"/>
+        <source>&amp;Native git/gpg</source>
+        <translation type="vanished">本地应用 git/gpg</translation>
+    </message>
+    <message>
+        <location filename="../configdialog.ui" line="484"/>
         <source>&amp;Use pass</source>
         <translation>应用 pass</translation>
     </message>
     <message>
-        <location filename="../configdialog.ui" line="476"/>
+        <location filename="../configdialog.ui" line="508"/>
         <source>Native</source>
         <translation>本地应用</translation>
     </message>
     <message>
-        <location filename="../configdialog.ui" line="482"/>
+        <location filename="../configdialog.ui" line="514"/>
         <source>git</source>
         <translation>git</translation>
     </message>
     <message>
-        <location filename="../configdialog.ui" line="492"/>
-        <location filename="../configdialog.ui" line="499"/>
-        <location filename="../configdialog.ui" line="526"/>
-        <location filename="../configdialog.ui" line="557"/>
-        <location filename="../configdialog.ui" line="856"/>
+        <location filename="../configdialog.ui" line="524"/>
+        <location filename="../configdialog.ui" line="531"/>
+        <location filename="../configdialog.ui" line="558"/>
+        <location filename="../configdialog.ui" line="589"/>
+        <location filename="../configdialog.ui" line="712"/>
         <source>...</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../configdialog.ui" line="506"/>
+        <location filename="../configdialog.ui" line="538"/>
         <source>gpg</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../configdialog.ui" line="519"/>
+        <location filename="../configdialog.ui" line="551"/>
         <source>pwgen</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../configdialog.ui" line="536"/>
+        <location filename="../configdialog.ui" line="568"/>
         <source>Pass</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../configdialog.ui" line="547"/>
+        <location filename="../configdialog.ui" line="579"/>
         <source>pass</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../configdialog.ui" line="566"/>
-        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;http://www.passwordstore.org/&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;www.passwordstore.org&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../configdialog.ui" line="642"/>
-        <source>Autoclear panel</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../configdialog.ui" line="776"/>
+        <location filename="../configdialog.ui" line="438"/>
         <source>Always on top</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../configdialog.ui" line="918"/>
+        <location filename="../configdialog.ui" line="774"/>
         <source>login
 url
 email</source>
@@ -141,31 +150,26 @@ email</source>
     </message>
     <message>
         <location filename="../configdialog.ui" line="240"/>
-        <location filename="../configdialog.ui" line="602"/>
         <source>Characters</source>
         <translation>字符</translation>
     </message>
     <message>
-        <location filename="../configdialog.ui" line="344"/>
-        <location filename="../configdialog.ui" line="752"/>
+        <location filename="../configdialog.ui" line="369"/>
         <source>Automatically add .gpg-id files</source>
         <translation>自动添加 gpg-id 文件</translation>
     </message>
     <message>
-        <location filename="../configdialog.ui" line="351"/>
-        <location filename="../configdialog.ui" line="759"/>
+        <location filename="../configdialog.ui" line="376"/>
         <source>Automatically push</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../configdialog.ui" line="358"/>
-        <location filename="../configdialog.ui" line="766"/>
+        <location filename="../configdialog.ui" line="383"/>
         <source>Automatically pull</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../configdialog.ui" line="293"/>
-        <location filename="../configdialog.ui" line="614"/>
         <source>Use pwgen</source>
         <translation>应用 pwgen</translation>
     </message>
@@ -176,128 +180,125 @@ email</source>
     <message>
         <location filename="../configdialog.ui" line="98"/>
         <location filename="../configdialog.ui" line="181"/>
-        <location filename="../configdialog.ui" line="633"/>
-        <location filename="../configdialog.ui" line="661"/>
         <source>Seconds</source>
         <translation>秒</translation>
     </message>
     <message>
         <location filename="../configdialog.ui" line="149"/>
-        <location filename="../configdialog.ui" line="670"/>
         <source>Hide password</source>
         <translation>隐藏密码</translation>
     </message>
     <message>
-        <location filename="../configdialog.ui" line="392"/>
-        <location filename="../configdialog.ui" line="677"/>
+        <location filename="../configdialog.ui" line="417"/>
         <source>Use TrayIcon</source>
         <translation>应用系统图标</translation>
     </message>
     <message>
-        <location filename="../configdialog.ui" line="406"/>
-        <location filename="../configdialog.ui" line="701"/>
+        <location filename="../configdialog.ui" line="431"/>
         <source>Hide on close</source>
         <translation>隐藏</translation>
     </message>
     <message>
-        <location filename="../configdialog.ui" line="332"/>
-        <location filename="../configdialog.ui" line="694"/>
+        <location filename="../configdialog.ui" line="355"/>
         <source>Use git</source>
         <translation>应用 git</translation>
     </message>
     <message>
         <location filename="../configdialog.ui" line="142"/>
-        <location filename="../configdialog.ui" line="684"/>
         <source>Hide content</source>
         <translation>隐藏内容</translation>
     </message>
     <message>
-        <location filename="../configdialog.ui" line="303"/>
-        <location filename="../configdialog.ui" line="711"/>
+        <location filename="../configdialog.ui" line="310"/>
         <source>Include special symbols </source>
         <translation>包含特殊文本</translation>
     </message>
     <message>
-        <location filename="../configdialog.ui" line="718"/>
         <source>Autoclear</source>
-        <translation type="unfinished">自动清除剪贴板内容</translation>
+        <translation type="obsolete">自动清除剪贴板内容</translation>
     </message>
     <message>
         <location filename="../configdialog.ui" line="278"/>
-        <location filename="../configdialog.ui" line="728"/>
         <source>ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../configdialog.ui" line="745"/>
         <source>Use characters</source>
-        <translation type="unfinished">应用字符</translation>
+        <translation type="obsolete">应用字符</translation>
     </message>
     <message>
-        <location filename="../configdialog.ui" line="399"/>
-        <location filename="../configdialog.ui" line="735"/>
+        <location filename="../configdialog.ui" line="424"/>
         <source>Start minimized</source>
         <translation>启动后自动隐藏</translation>
     </message>
     <message>
-        <location filename="../configdialog.ui" line="786"/>
+        <location filename="../configdialog.ui" line="477"/>
+        <source>Nati&amp;ve git/gpg</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../configdialog.ui" line="598"/>
+        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;https://www.passwordstore.org/&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;www.passwordstore.org&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../configdialog.ui" line="628"/>
         <source>Profiles</source>
         <translation>用户资料</translation>
     </message>
     <message>
-        <location filename="../configdialog.ui" line="820"/>
+        <location filename="../configdialog.ui" line="662"/>
         <source>Name</source>
         <translation>用户名</translation>
     </message>
     <message>
-        <location filename="../configdialog.ui" line="825"/>
+        <location filename="../configdialog.ui" line="667"/>
         <source>Path</source>
         <translation>路径</translation>
     </message>
     <message>
-        <location filename="../configdialog.ui" line="835"/>
+        <location filename="../configdialog.ui" line="677"/>
         <source>Add</source>
         <translation>添加</translation>
     </message>
     <message>
-        <location filename="../configdialog.ui" line="842"/>
+        <location filename="../configdialog.ui" line="691"/>
         <source>Delete</source>
         <translation>删除</translation>
     </message>
     <message>
-        <location filename="../configdialog.ui" line="849"/>
+        <location filename="../configdialog.ui" line="705"/>
         <source>Current password-store</source>
         <translation>当前密码路径</translation>
     </message>
     <message>
-        <location filename="../configdialog.ui" line="869"/>
+        <location filename="../configdialog.ui" line="725"/>
         <source>Template</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../configdialog.ui" line="890"/>
+        <location filename="../configdialog.ui" line="746"/>
         <source>Templates add extra fields in the password generation dialouge and in the password view.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../configdialog.ui" line="899"/>
+        <location filename="../configdialog.ui" line="755"/>
         <source>Use template</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../configdialog.ui" line="906"/>
+        <location filename="../configdialog.ui" line="762"/>
         <source>Show all lines beginning with a word followed by a colon as fields in password fields, not only the listed ones</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../configdialog.ui" line="909"/>
+        <location filename="../configdialog.ui" line="765"/>
         <source>Show all fields templated</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../configdialog.ui" line="933"/>
         <source>&lt;a href=&quot;http://QtPass.org/&quot;&gt;QtPass&lt;/a&gt; version </source>
-        <translation>&lt;a href=&quot;http://QtPass.org/&quot;&gt;QtPass&lt;/a&gt; 版本</translation>
+        <translation type="vanished">&lt;a href=&quot;http://QtPass.org/&quot;&gt;QtPass&lt;/a&gt; 版本</translation>
     </message>
     <message>
         <location filename="../configdialog.cpp" line="25"/>
@@ -397,19 +398,19 @@ email</source>
         <source>#           QtPass GPG key generator
 #
 #      first test version please comment
-# 
+#
 %echo Generating a default key
 Key-Type: default
 Subkey-Type: default
-Name-Real: 
+Name-Real:
 Name-Comment: QtPass
-Name-Email: 
+Name-Email:
 Expire-Date: 0
 %no-protection
 # Do a commit here, so that we can later print &quot;done&quot; :-)
 %commit
 %echo done</source>
-        <translation></translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../keygendialog.ui" line="178"/>
@@ -426,68 +427,95 @@ Expire-Date: 0
     </message>
     <message>
         <location filename="../mainwindow.ui" line="45"/>
+        <location filename="../mainwindow.ui" line="48"/>
         <source>Add</source>
         <translation>添加</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="68"/>
-        <location filename="../mainwindow.cpp" line="1633"/>
+        <location filename="../mainwindow.ui" line="72"/>
+        <location filename="../mainwindow.ui" line="75"/>
+        <location filename="../mainwindow.cpp" line="1685"/>
         <source>Edit</source>
         <translation>编辑</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="82"/>
-        <location filename="../mainwindow.cpp" line="1645"/>
+        <location filename="../mainwindow.ui" line="90"/>
+        <location filename="../mainwindow.ui" line="93"/>
+        <location filename="../mainwindow.cpp" line="1697"/>
         <source>Delete</source>
         <translation>删除</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="112"/>
+        <location filename="../mainwindow.ui" line="124"/>
+        <source>git push</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="127"/>
         <source>Push</source>
         <translation>上传</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="126"/>
+        <location filename="../mainwindow.ui" line="142"/>
+        <source>git pull</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="145"/>
         <source>Update</source>
         <translation>更新</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="156"/>
-        <location filename="../mainwindow.cpp" line="1627"/>
+        <location filename="../mainwindow.ui" line="176"/>
+        <source>Manage who can read password in folder</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="179"/>
+        <location filename="../mainwindow.cpp" line="1679"/>
         <source>Users</source>
         <translation>用户</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="170"/>
+        <location filename="../mainwindow.ui" line="194"/>
+        <source>Configuration</source>
+        <translation type="unfinished">设置</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="197"/>
         <source>Config</source>
         <translation>配置</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="200"/>
-        <location filename="../mainwindow.ui" line="203"/>
-        <location filename="../mainwindow.cpp" line="1662"/>
+        <location filename="../mainwindow.ui" line="228"/>
+        <location filename="../mainwindow.ui" line="231"/>
+        <location filename="../mainwindow.cpp" line="1714"/>
         <source>Copy Password</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="274"/>
-        <source>X</source>
-        <translation>重置</translation>
+        <location filename="../mainwindow.ui" line="299"/>
+        <source>Search Password</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="310"/>
+        <location filename="../mainwindow.ui" line="328"/>
         <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
 &lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
 p, li { white-space: pre-wrap; }
-&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Noto Sans&apos;; font-size:9pt; font-weight:400; font-style:normal;&quot;&gt;
-&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Helvetica Neue,Helvetica,Segoe UI,Arial,freesans,sans-serif&apos;; font-size:13pt; font-weight:600; color:#333333;&quot;&gt;QtPass&lt;/span&gt;&lt;span style=&quot; font-family:&apos;Helvetica Neue,Helvetica,Segoe UI,Arial,freesans,sans-serif&apos;; font-size:13pt; color:#333333;&quot;&gt; is a GUI for &lt;/span&gt;&lt;a href=&quot;http://www.passwordstore.org/&quot;&gt;&lt;span style=&quot; font-family:&apos;Helvetica Neue,Helvetica,Segoe UI,Arial,freesans,sans-serif&apos;; font-size:13pt; text-decoration: underline; color:#4183c4; background-color:transparent;&quot;&gt;pass&lt;/span&gt;&lt;/a&gt;&lt;span style=&quot; font-family:&apos;Helvetica Neue,Helvetica,Segoe UI,Arial,freesans,sans-serif&apos;; font-size:13pt; color:#333333;&quot;&gt;, the standard unix password manager.&lt;/span&gt;&lt;/p&gt;
+&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Noto Sans&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
+&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Helvetica Neue,Helvetica,Segoe UI,Arial,freesans,sans-serif&apos;; font-size:13pt; font-weight:600; color:#333333;&quot;&gt;QtPass&lt;/span&gt;&lt;span style=&quot; font-family:&apos;Helvetica Neue,Helvetica,Segoe UI,Arial,freesans,sans-serif&apos;; font-size:13pt; color:#333333;&quot;&gt; is a GUI for &lt;/span&gt;&lt;a href=&quot;https://www.passwordstore.org/&quot;&gt;&lt;span style=&quot; font-family:&apos;Helvetica Neue,Helvetica,Segoe UI,Arial,freesans,sans-serif&apos;; font-size:13pt; text-decoration: underline; color:#4183c4; background-color:transparent;&quot;&gt;pass&lt;/span&gt;&lt;/a&gt;&lt;span style=&quot; font-family:&apos;Helvetica Neue,Helvetica,Segoe UI,Arial,freesans,sans-serif&apos;; font-size:13pt; color:#333333;&quot;&gt;, the standard unix password manager.&lt;/span&gt;&lt;/p&gt;
 &lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Helvetica Neue,Helvetica,Segoe UI,Arial,freesans,sans-serif&apos;; font-size:13pt; color:#333333;&quot;&gt;&lt;br /&gt;Please report any &lt;/span&gt;&lt;a href=&quot;https://github.com/IJHack/qtpass/issues&quot;&gt;&lt;span style=&quot; font-family:&apos;Helvetica Neue,Helvetica,Segoe UI,Arial,freesans,sans-serif&apos;; font-size:13pt; text-decoration: underline; color:#4183c4;&quot;&gt;issues&lt;/span&gt;&lt;/a&gt;&lt;span style=&quot; font-family:&apos;Helvetica Neue,Helvetica,Segoe UI,Arial,freesans,sans-serif&apos;; font-size:13pt; color:#333333;&quot;&gt; you might have with this software.&lt;/span&gt;&lt;/p&gt;
-&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;a href=&quot;http://qtpass.org/&quot;&gt;&lt;span style=&quot; font-family:&apos;Helvetica Neue,Helvetica,Segoe UI,Arial,freesans,sans-serif&apos;; font-size:13pt; text-decoration: underline; color:#4183c4; background-color:transparent;&quot;&gt;Documentation&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;
+&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;a href=&quot;https://qtpass.org/&quot;&gt;&lt;span style=&quot; font-family:&apos;Helvetica Neue,Helvetica,Segoe UI,Arial,freesans,sans-serif&apos;; font-size:13pt; text-decoration: underline; color:#4183c4; background-color:transparent;&quot;&gt;Documentation&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;
 &lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;a href=&quot;https://github.com/IJHack/qtpass&quot;&gt;&lt;span style=&quot; font-family:&apos;Helvetica Neue,Helvetica,Segoe UI,Arial,freesans,sans-serif&apos;; font-size:13pt; text-decoration: underline; color:#4183c4; background-color:transparent;&quot;&gt;Source code&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="330"/>
+        <source>X</source>
+        <translation type="vanished">重置</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="348"/>
         <source>qtpass</source>
         <translation></translation>
     </message>
@@ -497,52 +525,52 @@ p, li { white-space: pre-wrap; }
         <translation>欢迎使用QtPass ％1</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="126"/>
+        <location filename="../mainwindow.cpp" line="141"/>
         <source>Failed to connect WebDAV:
 </source>
         <translation>无法连接 WebDAV:</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="137"/>
+        <location filename="../mainwindow.cpp" line="152"/>
         <source>QtPass WebDAV password</source>
         <translation>QtPass WebDAV 密码</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="138"/>
+        <location filename="../mainwindow.cpp" line="153"/>
         <source>Enter password to connect to WebDAV:</source>
         <translation>输入密码连接到 WebDAV:</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="154"/>
+        <location filename="../mainwindow.cpp" line="169"/>
         <source>fusedav exited unexpectedly
 </source>
         <translation>fusedav意外退出</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="158"/>
+        <location filename="../mainwindow.cpp" line="173"/>
         <source>Failed to start fusedav to connect WebDAV:
 </source>
         <translation>无法启动 fusedav 连接到WebDAV：</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="561"/>
-        <location filename="../mainwindow.cpp" line="573"/>
+        <location filename="../mainwindow.cpp" line="592"/>
+        <location filename="../mainwindow.cpp" line="604"/>
         <source>Updating password-store</source>
         <translation>更新密码路径</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1681"/>
+        <location filename="../mainwindow.cpp" line="1733"/>
         <source>New Folder: 
 (Will be placed in %1 )</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1793"/>
+        <location filename="../mainwindow.cpp" line="1849"/>
         <source>Password copied to clipboard</source>
         <translation>密码复制到剪贴板</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="740"/>
+        <location filename="../mainwindow.cpp" line="769"/>
         <source>Password hidden</source>
         <translation>隐藏密码</translation>
     </message>
@@ -557,75 +585,75 @@ p, li { white-space: pre-wrap; }
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="744"/>
+        <location filename="../mainwindow.cpp" line="773"/>
         <source>Content hidden</source>
         <translation>隐藏内容</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="835"/>
+        <location filename="../mainwindow.cpp" line="864"/>
         <source>Clipboard cleared</source>
         <translation>剪贴板已清除</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="837"/>
+        <location filename="../mainwindow.cpp" line="866"/>
         <source>Clipboard not cleared</source>
         <translation>剪贴板未清除</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="850"/>
+        <location filename="../mainwindow.cpp" line="879"/>
         <source>Password and Content hidden</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="900"/>
+        <location filename="../mainwindow.cpp" line="930"/>
         <source>QProcess::FailedToStart</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="903"/>
+        <location filename="../mainwindow.cpp" line="933"/>
         <source>QProcess::Crashed</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="906"/>
+        <location filename="../mainwindow.cpp" line="936"/>
         <source>QProcess::Timedout</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="909"/>
+        <location filename="../mainwindow.cpp" line="939"/>
         <source>QProcess::ReadError</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="912"/>
+        <location filename="../mainwindow.cpp" line="942"/>
         <source>QProcess::WriteError</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="915"/>
+        <location filename="../mainwindow.cpp" line="945"/>
         <source>QProcess::UnknownError</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="959"/>
+        <location filename="../mainwindow.cpp" line="990"/>
         <source>Looking for: %1</source>
         <translation>查找：%1</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="644"/>
-        <location filename="../mainwindow.cpp" line="1095"/>
-        <location filename="../mainwindow.cpp" line="1256"/>
+        <location filename="../mainwindow.cpp" line="675"/>
+        <location filename="../mainwindow.cpp" line="1121"/>
+        <location filename="../mainwindow.cpp" line="1296"/>
         <source>Can not edit</source>
         <translation>无法编辑</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1096"/>
+        <location filename="../mainwindow.cpp" line="1122"/>
         <source>Could not read encryption key to use, .gpg-id file missing or invalid.</source>
         <translation>无法读取加密密钥，gpg-id丢失或无效</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1141"/>
-        <location filename="../mainwindow.cpp" line="1680"/>
+        <location filename="../mainwindow.cpp" line="1167"/>
+        <location filename="../mainwindow.cpp" line="1732"/>
         <source>New file</source>
         <translation>新文件</translation>
     </message>
@@ -634,86 +662,86 @@ p, li { white-space: pre-wrap; }
         <translation type="vanished">新密码文件，将放置在文件夹 ％1：</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1166"/>
+        <location filename="../mainwindow.cpp" line="1191"/>
         <source>Delete password?</source>
         <translation>删除密码？</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1167"/>
-        <location filename="../mainwindow.cpp" line="1195"/>
+        <location filename="../mainwindow.cpp" line="1192"/>
+        <location filename="../mainwindow.cpp" line="1220"/>
         <source>Are you sure you want to delete %1?</source>
         <translation>您确定要删除 ％1 吗？</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1194"/>
+        <location filename="../mainwindow.cpp" line="1219"/>
         <source>Delete folder?</source>
         <translation>删除文件夹？</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="645"/>
-        <location filename="../mainwindow.cpp" line="1257"/>
+        <location filename="../mainwindow.cpp" line="676"/>
+        <location filename="../mainwindow.cpp" line="1297"/>
         <source>Selected password file does not exist, not able to edit</source>
         <translation>选定的密码文件不存在，不可编辑</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1142"/>
+        <location filename="../mainwindow.cpp" line="1168"/>
         <source>New password file: 
 (Will be placed in %1 )</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1313"/>
+        <location filename="../mainwindow.cpp" line="1353"/>
         <source>Can not get key list</source>
         <translation>无法获得密钥列表</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1314"/>
+        <location filename="../mainwindow.cpp" line="1354"/>
         <source>Unable to get list of available gpg keys</source>
         <translation>无法获取可用的GPG密钥列表</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1345"/>
+        <location filename="../mainwindow.cpp" line="1385"/>
         <source>Key not found in keyring</source>
         <translation>密钥未找到</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1366"/>
+        <location filename="../mainwindow.cpp" line="1406"/>
         <source>Cannot update</source>
         <translation>无法更新</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1367"/>
+        <location filename="../mainwindow.cpp" line="1407"/>
         <source>Failed to open .gpg-id for writing.</source>
         <translation>无法打开 .gpg-id写入</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1380"/>
+        <location filename="../mainwindow.cpp" line="1420"/>
         <source>Check selected users!</source>
         <translation>核对所选用户！</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1381"/>
+        <location filename="../mainwindow.cpp" line="1421"/>
         <source>None of the selected keys have a secret key available.
 You will not be able to decrypt any newly added passwords!</source>
         <translation>密钥不可用：您将无法解密任何新添加的密码！</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1467"/>
+        <location filename="../mainwindow.cpp" line="1507"/>
         <source>Generating GPG key pair</source>
         <translation>生成GPG密钥对</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1508"/>
+        <location filename="../mainwindow.cpp" line="1548"/>
         <source>Profile changed to %1</source>
         <translation>用户名更改为％1</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1625"/>
+        <location filename="../mainwindow.cpp" line="1677"/>
         <source>Add folder</source>
         <translation>添加文件夹</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1626"/>
+        <location filename="../mainwindow.cpp" line="1678"/>
         <source>Add password</source>
         <translation>添加密码</translation>
     </message>
@@ -722,22 +750,22 @@ You will not be able to decrypt any newly added passwords!</source>
         <translation type="vanished">新文件夹，将放置在文件夹％1：</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1745"/>
+        <location filename="../mainwindow.cpp" line="1801"/>
         <source>No characters chosen</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1746"/>
+        <location filename="../mainwindow.cpp" line="1802"/>
         <source>Can&apos;t generate password, there are no characters to choose from set in the configuration!</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1764"/>
+        <location filename="../mainwindow.cpp" line="1820"/>
         <source>Timed out</source>
         <translation>超时</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1765"/>
+        <location filename="../mainwindow.cpp" line="1821"/>
         <source>Can&apos;t start process, previous one is still running!</source>
         <translation>无法启动程序, 先前程序仍在运行！</translation>
     </message>
@@ -746,16 +774,17 @@ You will not be able to decrypt any newly added passwords!</source>
     <name>PasswordDialog</name>
     <message>
         <location filename="../passworddialog.ui" line="14"/>
+        <location filename="../passworddialog.ui" line="55"/>
         <source>Password</source>
         <translation>密码</translation>
     </message>
     <message>
-        <location filename="../passworddialog.ui" line="59"/>
+        <location filename="../passworddialog.ui" line="65"/>
         <source>Generate</source>
         <translation>生成</translation>
     </message>
     <message>
-        <location filename="../passworddialog.ui" line="68"/>
+        <location filename="../passworddialog.ui" line="74"/>
         <source>Show password</source>
         <translation>显示密码</translation>
     </message>
@@ -763,7 +792,7 @@ You will not be able to decrypt any newly added passwords!</source>
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../main.cpp" line="41"/>
+        <location filename="../main.cpp" line="70"/>
         <source>LTR</source>
         <translation type="unfinished"></translation>
     </message>
@@ -795,22 +824,26 @@ Red entries are not valid, you will not be able to encrypt to these.</source>
 红色条目为无效，您无法对其加密。</translation>
     </message>
     <message>
-        <location filename="../usersdialog.ui" line="62"/>
-        <source>X</source>
-        <translation>重置</translation>
+        <location filename="../usersdialog.ui" line="65"/>
+        <source>Search Users</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../usersdialog.ui" line="69"/>
+        <source>X</source>
+        <translation type="vanished">重置</translation>
+    </message>
+    <message>
+        <location filename="../usersdialog.ui" line="72"/>
         <source>Show unusable keys</source>
         <translation>显示不可用密钥</translation>
     </message>
     <message>
-        <location filename="../usersdialog.cpp" line="52"/>
+        <location filename="../usersdialog.cpp" line="56"/>
         <source>created</source>
         <translation>创建完成</translation>
     </message>
     <message>
-        <location filename="../usersdialog.cpp" line="56"/>
+        <location filename="../usersdialog.cpp" line="60"/>
         <source>expires</source>
         <translation>过期</translation>
     </message>
