@@ -1,7 +1,36 @@
+#include "mainwindow.h"
 #include <QApplication>
 #include <QTranslator>
-#include "mainwindow.h"
 
+/*! \mainpage QtPass
+ *
+ * \section intro_sec Introduction
+ *
+ * QtPass is a multi-platform GUI for pass, the standard unix password manager.
+ *
+ * \section install_sec Installation
+ *
+ * \subsection dependencies Dependencies
+ *
+ * - QtPass requires Qt 4.8 or later, preferably Qt5.5 or later.
+ * - The Linguist package is required to compile the translations.
+ * - For use of the fallback icons the SVG library is required.
+ *
+ * At runtime the only real dependency is gpg2 but to make the most of it, you'll need git and pass too.
+ *
+ * \subsection source From source
+ *
+ * On most *nix systems all you need is:
+ *
+ * `qmake && make && make install`
+ */
+
+/**
+ * @brief main
+ * @param argc
+ * @param argv
+ * @return
+ */
 int main(int argc, char *argv[]) {
   // check for stupid apple psid or whatever flag
   QString text = "";
@@ -40,13 +69,15 @@ int main(int argc, char *argv[]) {
   app.installTranslator(&translator);
   app.setLayoutDirection(QObject::tr("LTR") == "RTL" ? Qt::RightToLeft
                                                      : Qt::LeftToRight);
-
   MainWindow w;
 
+  QObject::connect(&app, SIGNAL(aboutToQuit()), &w, SLOT(clearClipboard()));
+
   app.setActiveWindow(&w);
   app.setWindowIcon(QIcon(":artwork/icon.png"));
   w.setApp(&app);
   w.setText(text);
   w.show();
+
   return app.exec();
 }
