@@ -1,13 +1,13 @@
 #include "mainwindow.h"
 #include <QClipboard>
-#include <QDebug>
-#include <QInputDialog>
-#include <QMessageBox>
-#include <QTimer>
-#include <QFileInfo>
-#include <QQueue>
 #include <QCloseEvent>
+#include <QDebug>
+#include <QFileInfo>
+#include <QInputDialog>
 #include <QLabel>
+#include <QMessageBox>
+#include <QQueue>
+#include <QTimer>
 #ifdef Q_OS_WIN
 #define WIN32_LEAN_AND_MEAN /*_KILLING_MACHINE*/
 #define WIN32_EXTRA_LEAN
@@ -15,11 +15,11 @@
 #include <winnetwk.h>
 #undef DELETE
 #endif
-#include "ui_mainwindow.h"
 #include "configdialog.h"
-#include "usersdialog.h"
 #include "keygendialog.h"
 #include "passworddialog.h"
+#include "ui_mainwindow.h"
+#include "usersdialog.h"
 #include "util.h"
 
 /**
@@ -61,9 +61,14 @@ MainWindow::MainWindow(QWidget *parent)
   ui->addButton->addAction(actionAddPassword);
   ui->addButton->addAction(actionAddFolder);
 
-  connect(actionAddPassword, SIGNAL(triggered()), this, SLOT(on_addButton_clicked()));
+  connect(actionAddPassword, SIGNAL(triggered()), this,
+          SLOT(on_addButton_clicked()));
   connect(actionAddFolder, SIGNAL(triggered()), this, SLOT(addFolder()));
   qsrand(QDateTime::currentDateTime().toTime_t());
+
+#if QT_VERSION >= 0x050200
+  ui->lineEdit->setClearButtonEnabled(true);
+#endif
 }
 
 void MainWindow::focusInput() {
@@ -102,6 +107,16 @@ QSettings &MainWindow::getSettings() {
   return *settings;
 }
 
+void MainWindow::changeEvent(QEvent *event) {
+  QWidget::changeEvent(event);
+  if (event->type() == QEvent::ActivationChange) {
+    if (this->isActiveWindow()) {
+      ui->lineEdit->selectAll();
+      ui->lineEdit->setFocus();
+    }
+  }
+}
+
 void MainWindow::mountWebDav() {
 #ifdef Q_OS_WIN
   char dst[20] = {0};
@@ -236,12 +251,15 @@ bool MainWindow::checkConfig() {
   profile = settings.value("profile").toString();
   settings.beginGroup("profiles");
   QStringList keys = settings.childKeys();
-  foreach(QString key, keys)
+  foreach (QString key, keys)
     profiles[key] = settings.value(key).toString();
   settings.endGroup();
 
   useGit = (settings.value("useGit") == "true");
   usePwgen = (settings.value("usePwgen") == "true");
+  avoidCapitals = settings.value("avoidCapitals").toBool();
+  avoidNumbers = settings.value("avoidNumbers").toBool();
+  lessRandom = settings.value("lessRandom").toBool();
   useSymbols = (settings.value("useSymbols") == "true");
   passwordLength = settings.value("passwordLength").toInt();
   passwordChars = settings.value("passwordChars").toString();
@@ -252,9 +270,9 @@ bool MainWindow::checkConfig() {
   alwaysOnTop = settings.value("alwaysOnTop").toBool();
 
   if (alwaysOnTop) {
-      Qt::WindowFlags flags = windowFlags();
-      this->setWindowFlags(flags | Qt::WindowStaysOnTopHint);
-      this->show();
+    Qt::WindowFlags flags = windowFlags();
+    this->setWindowFlags(flags | Qt::WindowStaysOnTopHint);
+    this->show();
   }
 
   autoPull = settings.value("autoPull").toBool();
@@ -372,11 +390,13 @@ bool MainWindow::checkConfig() {
   if (!useGit || (gitExecutable.isEmpty() && passExecutable.isEmpty())) {
     ui->pushButton->hide();
     ui->updateButton->hide();
-    ui->horizontalSpacer->changeSize(0, 20, QSizePolicy::Maximum, QSizePolicy::Minimum);
+    ui->horizontalSpacer->changeSize(0, 20, QSizePolicy::Maximum,
+                                     QSizePolicy::Minimum);
   } else {
     ui->pushButton->show();
     ui->updateButton->show();
-    ui->horizontalSpacer->changeSize(24, 24, QSizePolicy::Minimum, QSizePolicy::Minimum);
+    ui->horizontalSpacer->changeSize(24, 24, QSizePolicy::Minimum,
+                                     QSizePolicy::Minimum);
   }
 
   startupPhase = false;
@@ -413,6 +433,9 @@ void MainWindow::config() {
   d->useGit(useGit);
   d->setPwgenPath(pwgenExecutable);
   d->usePwgen(usePwgen);
+  d->avoidCapitals(avoidCapitals);
+  d->avoidNumbers(avoidNumbers);
+  d->lessRandom(lessRandom);
   d->useSymbols(useSymbols);
   d->setPasswordLength(passwordLength);
   d->setPasswordChars(passwordChars);
@@ -423,7 +446,7 @@ void MainWindow::config() {
   d->autoPush(autoPush);
   d->alwaysOnTop(alwaysOnTop);
   if (startupPhase)
-    d->wizard();  // does shit
+    d->wizard(); // does shit
   if (d->exec()) {
     if (d->result() == QDialog::Accepted) {
       passExecutable = d->getPassPath();
@@ -446,6 +469,9 @@ void MainWindow::config() {
       useGit = d->useGit();
       pwgenExecutable = d->getPwgenPath();
       usePwgen = d->usePwgen();
+      avoidCapitals = d->avoidCapitals();
+      avoidNumbers = d->avoidNumbers();
+      lessRandom = d->lessRandom();
       useSymbols = d->useSymbols();
       passwordLength = d->getPasswordLength();
       passwordChars = d->getPasswordChars();
@@ -489,6 +515,9 @@ void MainWindow::config() {
       settings.setValue("useGit", useGit ? "true" : "false");
       settings.setValue("pwgenExecutable", pwgenExecutable);
       settings.setValue("usePwgen", usePwgen ? "true" : "false");
+      settings.setValue("avoidCapitals", avoidCapitals ? "true" : "false");
+      settings.setValue("avoidNumbers", avoidNumbers ? "true" : "false");
+      settings.setValue("lessRandom", lessRandom ? "true" : "false");
       settings.setValue("useSymbols", useSymbols ? "true" : "false");
       settings.setValue("passwordLength", passwordLength);
       settings.setValue("passwordChars", passwordChars);
@@ -496,16 +525,16 @@ void MainWindow::config() {
       settings.setValue("passTemplate", passTemplate);
       settings.setValue("templateAllFields", templateAllFields);
       settings.setValue("autoPull", autoPull ? "true" : "false");
-      settings.setValue("autoPush", autoPush ? "true" : "false");      
+      settings.setValue("autoPush", autoPush ? "true" : "false");
       settings.setValue("alwaysOnTop", alwaysOnTop ? "true" : "false");
 
       if (alwaysOnTop) {
-          Qt::WindowFlags flags = windowFlags();
-          this->setWindowFlags(flags | Qt::WindowStaysOnTopHint);
-          this->show();
+        Qt::WindowFlags flags = windowFlags();
+        this->setWindowFlags(flags | Qt::WindowStaysOnTopHint);
+        this->show();
       } else {
-          this->setWindowFlags(Qt::Window);
-          this->show();
+        this->setWindowFlags(Qt::Window);
+        this->show();
       }
 
       if (!profiles.isEmpty()) {
@@ -537,13 +566,15 @@ void MainWindow::config() {
         config();
       updateEnv();
       if (!useGit || (gitExecutable.isEmpty() && passExecutable.isEmpty())) {
-          ui->pushButton->hide();
-          ui->updateButton->hide();
-          ui->horizontalSpacer->changeSize(0, 20, QSizePolicy::Maximum, QSizePolicy::Minimum);
+        ui->pushButton->hide();
+        ui->updateButton->hide();
+        ui->horizontalSpacer->changeSize(0, 20, QSizePolicy::Maximum,
+                                         QSizePolicy::Minimum);
       } else {
-          ui->pushButton->show();
-          ui->updateButton->show();
-          ui->horizontalSpacer->changeSize(24, 24, QSizePolicy::Minimum, QSizePolicy::Minimum);
+        ui->pushButton->show();
+        ui->updateButton->show();
+        ui->horizontalSpacer->changeSize(24, 24, QSizePolicy::Minimum,
+                                         QSizePolicy::Minimum);
       }
       if (useTrayIcon && tray == NULL)
         initTrayIcon();
@@ -584,11 +615,11 @@ QString MainWindow::getDir(const QModelIndex &index, bool forPass) {
     return forPass ? "" : abspath;
   QFileInfo info = model.fileInfo(proxyModel.mapToSource(index));
   QString filePath =
-      (info.isFile() ? info.absolutePath() : info.absoluteFilePath()) + '/';
+      (info.isFile() ? info.absolutePath() : info.absoluteFilePath());
   if (forPass) {
-    filePath.replace(QRegExp("^" + passStore), "");
-    filePath.replace(QRegExp("^" + abspath), "");
+    filePath = QDir(abspath).relativeFilePath(filePath);
   }
+  filePath += '/';
   return filePath;
 }
 
@@ -598,8 +629,8 @@ QString MainWindow::getFile(const QModelIndex &index, bool forPass) {
     return QString();
   QString filePath = model.filePath(proxyModel.mapToSource(index));
   if (forPass) {
+    filePath = QDir(passStore).relativeFilePath(filePath);
     filePath.replace(QRegExp("\\.gpg$"), "");
-    filePath.replace(QRegExp("^" + passStore), "");
   }
   return filePath;
 }
@@ -632,7 +663,7 @@ void MainWindow::on_treeView_clicked(const QModelIndex &index) {
  * @param index
  */
 void MainWindow::on_treeView_doubleClicked(const QModelIndex &index) {
-    // TODO: do nothing when clicked on folder
+  // TODO: do nothing when clicked on folder
   QFileInfo fileOrFolder =
       model.fileInfo(proxyModel.mapToSource(ui->treeView->currentIndex()));
   QString file = "";
@@ -649,8 +680,6 @@ void MainWindow::on_treeView_doubleClicked(const QModelIndex &index) {
   }
 }
 
-
-
 /**
  * @brief MainWindow::executePass
  * @param args
@@ -744,7 +773,7 @@ void MainWindow::readyRead(bool finished = false) {
           output = "***" + tr("Content hidden") + "***";
       }
 
-      if (useTemplate) {
+      if (useTemplate && !hideContent) {
         while (ui->formLayout->count() > 0) {
           QLayoutItem *item = ui->formLayout->takeAt(0);
           delete item->widget();
@@ -766,14 +795,14 @@ void MainWindow::readyRead(bool finished = false) {
             if (templateAllFields || passTemplate.contains(field)) {
               QString value = token.right(token.length() - colon - 1);
               if (!passTemplate.contains(field) && value.startsWith("//"))
-                continue;  // colon is probably from a url
+                continue; // colon is probably from a url
               QLineEdit *line = new QLineEdit();
               line->setObjectName(field);
               line->setText(value);
               line->setReadOnly(true);
               ui->formLayout->addRow(new QLabel(field), line);
               tokens.removeAt(j);
-              --j;  // tokens.length() also got shortened by the remove..
+              --j; // tokens.length() also got shortened by the remove..
             }
           }
         }
@@ -879,6 +908,7 @@ void MainWindow::enableUiElements(bool state) {
   ui->updateButton->setEnabled(state);
   ui->treeView->setEnabled(state);
   ui->lineEdit->setEnabled(state);
+  ui->lineEdit->installEventFilter(this);
   ui->addButton->setEnabled(state);
   ui->usersButton->setEnabled(state);
   ui->configButton->setEnabled(state);
@@ -951,7 +981,8 @@ QString MainWindow::getGpgExecutable() { return gpgExecutable; }
 void MainWindow::on_configButton_clicked() { config(); }
 
 /**
- * @brief Executes when the string in the search box changes, collapses the TreeView
+ * @brief Executes when the string in the search box changes, collapses the
+ * TreeView
  * @param arg1
  */
 void MainWindow::on_lineEdit_textChanged(const QString &arg1) {
@@ -966,11 +997,11 @@ void MainWindow::on_lineEdit_textChanged(const QString &arg1) {
   selectFirstFile();
 }
 
-
 /**
  * @brief MainWindow::on_lineEdit_returnPressed
  */
 void MainWindow::on_lineEdit_returnPressed() {
+  qDebug() << "on_lineEdit_returnPressed";
   selectFirstFile();
   on_treeView_clicked(ui->treeView->currentIndex());
 }
@@ -1002,11 +1033,6 @@ QModelIndex MainWindow::firstFile(QModelIndex parentIndex) {
   return index;
 }
 
-/**
- * @brief MainWindow::on_clearButton_clicked
- */
-void MainWindow::on_clearButton_clicked() { ui->lineEdit->clear(); }
-
 /**
  * @brief MainWindow::getRecipientList
  * @param for_file
@@ -1053,7 +1079,7 @@ QString MainWindow::getRecipientString(QString for_file, QString separator,
   QStringList recipients_list = getRecipientList(for_file);
   if (count)
     *count = recipients_list.size();
-  foreach(const QString recipient, recipients_list)
+  foreach (const QString recipient, recipients_list)
     recipients_str += separator + '"' + recipient + '"';
   return recipients_str;
 }
@@ -1104,9 +1130,8 @@ void MainWindow::setPassword(QString file, bool overwrite, bool isNew = false) {
     if (!useWebDav && useGit) {
       if (!overwrite)
         executeWrapper(gitExecutable, "add \"" + file + '"');
-      QString path = file;
+      QString path = QDir(passStore).relativeFilePath(file);
       path.replace(QRegExp("\\.gpg$"), "");
-      path.replace(QRegExp("^" + passStore), "");
       executeWrapper(gitExecutable, "commit \"" + file + "\" -m \"" +
                                         (overwrite ? "Edit" : "Add") + " for " +
                                         path + " using QtPass.\"");
@@ -1121,20 +1146,21 @@ void MainWindow::setPassword(QString file, bool overwrite, bool isNew = false) {
  */
 void MainWindow::on_addButton_clicked() {
   // Check for active and selected encryption key
-//  QList<UserInfo> users=listKeys();
-//  UserInfo testuser;
-//  bool noUserEnabled = false;
-//  // Check if at least one active user is selected
-//  for (int i = 0; i< users.length();i++) {
-//    testuser = users[i];
-//    noUserEnabled = users[i].enabled | noUserEnabled;
-//  }
-//  // Error if no user is enabled, so a password doesn't get saved
-//  if (noUserEnabled==false) {
-//    QMessageBox::critical(this, tr("Can not get key list"),
-//                          tr("No Key for encryption selected! \nPlease select a valid key pair in the users dialouge"));
-//    return;
-//  }
+  //  QList<UserInfo> users=listKeys();
+  //  UserInfo testuser;
+  //  bool noUserEnabled = false;
+  //  // Check if at least one active user is selected
+  //  for (int i = 0; i< users.length();i++) {
+  //    testuser = users[i];
+  //    noUserEnabled = users[i].enabled | noUserEnabled;
+  //  }
+  //  // Error if no user is enabled, so a password doesn't get saved
+  //  if (noUserEnabled==false) {
+  //    QMessageBox::critical(this, tr("Can not get key list"),
+  //                          tr("No Key for encryption selected! \nPlease
+  //                          select a valid key pair in the users dialouge"));
+  //    return;
+  //  }
   bool ok;
   QString dir = getDir(ui->treeView->currentIndex(), usePass);
   QString file = QInputDialog::getText(
@@ -1151,7 +1177,6 @@ void MainWindow::on_addButton_clicked() {
   setPassword(file, false, true);
 }
 
-
 /**
  * @brief MainWindow::on_deleteButton_clicked
  */
@@ -1178,7 +1203,7 @@ void MainWindow::on_deleteButton_clicked() {
       if (useGit) {
         executeWrapper(gitExecutable, "rm -f \"" + file + '"');
         executeWrapper(gitExecutable,
-                       "commit \"" + file + "\" -m \" Remove for " +
+                       "commit \"" + file + "\" -m \"Remove for " +
                            getFile(ui->treeView->currentIndex(), true) +
                            " using QtPass.\"");
         if (autoPush)
@@ -1193,26 +1218,41 @@ void MainWindow::on_deleteButton_clicked() {
     if (QMessageBox::question(
             this, tr("Delete folder?"),
             tr("Are you sure you want to delete %1?")
-            .arg(QDir::separator() +
-            getDir(ui->treeView->currentIndex(), true)),
+                .arg(QDir::separator() +
+                     getDir(ui->treeView->currentIndex(), true)),
             QMessageBox::Yes | QMessageBox::No) != QMessageBox::Yes) {
       return;
     } else {
-      if (useGit) {
-        executeWrapper(gitExecutable, "rm -rf \"" + file + '"');
-        executeWrapper(gitExecutable,
-                       "commit \"" + file + "\" -m \" Remove for " +
-                           getFile(ui->treeView->currentIndex(), true) +
-                           " using QtPass.\"");
-        if (autoPush)
+      if (usePass) {
+        currentAction = DELETE;
+        executePass("rm -rf \"" + file + '"');
+        if (useGit && autoPush) {
           on_pushButton_clicked();
+        }
       } else {
+        if (useGit) {
+          executeWrapper(gitExecutable, "rm -rf \"" + file + '"');
 #if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
-        QDir dir(file);
-        dir.removeRecursively();
+          QDir dir(file);
+          dir.removeRecursively();
 #else
-        removeDir(passStore + file);
+          removeDir(passStore + file);
 #endif
+          executeWrapper(gitExecutable,
+                         "commit \"" + file + "\" -m \"Remove for " +
+                             getFile(ui->treeView->currentIndex(), true) +
+                             " using QtPass.\"");
+          if (autoPush) {
+            on_pushButton_clicked();
+          }
+        } else {
+#if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
+          QDir dir(file);
+          dir.removeRecursively();
+#else
+          removeDir(passStore + file);
+#endif
+        }
       }
     }
   }
@@ -1229,7 +1269,7 @@ bool MainWindow::removeDir(const QString &dirName) {
   QDir dir(dirName);
 
   if (dir.exists(dirName)) {
-    Q_FOREACH(QFileInfo info,
+    Q_FOREACH (QFileInfo info,
                dir.entryInfoList(QDir::NoDotAndDotDot | QDir::System |
                                      QDir::Hidden | QDir::AllDirs | QDir::Files,
                                  QDir::DirsFirst)) {
@@ -1279,7 +1319,7 @@ QList<UserInfo> MainWindow::listKeys(QString keystring, bool secret) {
   QStringList keys = QString(process->readAllStandardOutput())
                          .split(QRegExp("[\r\n]"), QString::SkipEmptyParts);
   UserInfo current_user;
-  foreach(QString key, keys) {
+  foreach (QString key, keys) {
     QStringList props = key.split(':');
     if (props.size() < 10)
       continue;
@@ -1315,7 +1355,7 @@ void MainWindow::on_usersButton_clicked() {
     return;
   }
   QList<UserInfo> secret_keys = listKeys("", true);
-  foreach(const UserInfo &sec, secret_keys) {
+  foreach (const UserInfo &sec, secret_keys) {
     for (QList<UserInfo>::iterator it = users.begin(); it != users.end(); ++it)
       if (sec.key_id == it->key_id)
         it->have_secret = true;
@@ -1329,7 +1369,7 @@ void MainWindow::on_usersButton_clicked() {
       getRecipientString(dir.isEmpty() ? "" : dir, " ", &count);
   if (!recipients.isEmpty())
     selected_users = listKeys(recipients);
-  foreach(const UserInfo &sel, selected_users) {
+  foreach (const UserInfo &sel, selected_users) {
     for (QList<UserInfo>::iterator it = users.begin(); it != users.end(); ++it)
       if (sel.key_id == it->key_id)
         it->enabled = true;
@@ -1337,7 +1377,7 @@ void MainWindow::on_usersButton_clicked() {
   if (count > selected_users.size()) {
     // Some keys seem missing from keyring, add them separately
     QStringList recipients = getRecipientList(dir.isEmpty() ? "" : dir);
-    foreach(const QString recipient, recipients) {
+    foreach (const QString recipient, recipients) {
       if (listKeys(recipient).size() < 1) {
         UserInfo i;
         i.enabled = true;
@@ -1354,43 +1394,59 @@ void MainWindow::on_usersButton_clicked() {
     return;
   }
   d.setUsers(NULL);
-  QString gpgIdFile = dir + ".gpg-id";
-  QFile gpgId(gpgIdFile);
-  bool addFile = false;
-  if (addGPGId) {
-    QFileInfo checkFile(gpgIdFile);
-    if (!checkFile.exists() || !checkFile.isFile())
-      addFile = true;
-  }
-  if (!gpgId.open(QIODevice::WriteOnly | QIODevice::Text)) {
-    QMessageBox::critical(this, tr("Cannot update"),
-                          tr("Failed to open .gpg-id for writing."));
-    return;
-  }
-  bool secret_selected = false;
-  foreach(const UserInfo &user, users) {
-    if (user.enabled) {
-      gpgId.write((user.key_id + "\n").toUtf8());
-      secret_selected |= user.have_secret;
-    }
-  }
-  gpgId.close();
-  if (!secret_selected) {
-    QMessageBox::critical(
-        this, tr("Check selected users!"),
-        tr("None of the selected keys have a secret key available.\n"
-           "You will not be able to decrypt any newly added passwords!"));
-  }
-  if (!useWebDav && useGit && !gitExecutable.isEmpty()) {
-    if (addFile)
-      executeWrapper(gitExecutable, "add \"" + gpgIdFile + '"');
-    QString path = gpgIdFile;
-    path.replace(QRegExp("\\.gpg$"), "");
-    executeWrapper(gitExecutable, "commit \"" + gpgIdFile + "\" -m \"Added " +
-                                      path + " using QtPass.\"");
-    if (autoPush)
-      on_pushButton_clicked();
+
+  if (usePass) {
+      QString gpgIds = "";
+      foreach (const UserInfo &user, users) {
+        if (user.enabled) {
+          gpgIds += user.key_id + " ";
+        }
+      }
+      executePass("init --path=" + dir + " " + gpgIds);
+  } else {
+      QString gpgIdFile = dir + ".gpg-id";
+      QFile gpgId(gpgIdFile);
+      bool addFile = false;
+      if (addGPGId) {
+        QFileInfo checkFile(gpgIdFile);
+        if (!checkFile.exists() || !checkFile.isFile())
+          addFile = true;
+      }
+      if (!gpgId.open(QIODevice::WriteOnly | QIODevice::Text)) {
+        QMessageBox::critical(this, tr("Cannot update"),
+                              tr("Failed to open .gpg-id for writing."));
+        return;
+      }
+      bool secret_selected = false;
+      foreach (const UserInfo &user, users) {
+        if (user.enabled) {
+          gpgId.write((user.key_id + "\n").toUtf8());
+          secret_selected |= user.have_secret;
+        }
+      }
+      gpgId.close();
+      if (!secret_selected) {
+        QMessageBox::critical(
+            this, tr("Check selected users!"),
+            tr("None of the selected keys have a secret key available.\n"
+               "You will not be able to decrypt any newly added passwords!"));
+      }
+
+      if (!useWebDav && useGit && !gitExecutable.isEmpty()) {
+        if (addFile)
+          executeWrapper(gitExecutable, "add \"" + gpgIdFile + '"');
+        QString path = gpgIdFile;
+        path.replace(QRegExp("\\.gpg$"), "");
+        executeWrapper(gitExecutable, "commit \"" + gpgIdFile + "\" -m \"Added " +
+                                          path + " using QtPass.\"");
+        if (autoPush)
+          on_pushButton_clicked();
+      }
+
+      reencryptPath(dir);
   }
+
+
 }
 
 /**
@@ -1452,7 +1508,7 @@ QStringList MainWindow::getSecretKeys() {
   if (keys.size() == 0)
     return names;
 
-  foreach(const UserInfo &sec, keys)
+  foreach (const UserInfo &sec, keys)
     names << sec.name;
 
   return names;
@@ -1491,7 +1547,7 @@ void MainWindow::updateProfileBox() {
     }
   }
   int index = ui->profileBox->findText(profile);
-  if (index != -1)  // -1 for not found
+  if (index != -1) // -1 for not found
     ui->profileBox->setCurrentIndex(index);
 }
 
@@ -1566,6 +1622,7 @@ void MainWindow::closeEvent(QCloseEvent *event) {
     this->hide();
     event->ignore();
   } else {
+    clearClipboard();
     settings->beginGroup("mainwindow");
     settings->setValue("geometry", saveGeometry());
     settings->setValue("savestate", saveState());
@@ -1581,20 +1638,32 @@ void MainWindow::closeEvent(QCloseEvent *event) {
   }
 }
 
-void MainWindow::keyPressEvent(QKeyEvent * event) {
-    switch (event->key()) {
-    case Qt::Key_Delete:
-        on_deleteButton_clicked();
-        break;
-    case Qt::Key_Return:
-    case Qt::Key_Enter:
-        on_editButton_clicked();
-        break;
-    default:
-        break;
+bool MainWindow::eventFilter(QObject *obj, QEvent *event) {
+  if (obj == ui->lineEdit && event->type() == QEvent::KeyPress) {
+    QKeyEvent *key = static_cast<QKeyEvent *>(event);
+    if (key->key() == Qt::Key_Down) {
+      ui->treeView->setFocus();
     }
+  }
+  return QObject::eventFilter(obj, event);
 }
 
+void MainWindow::keyPressEvent(QKeyEvent *event) {
+  switch (event->key()) {
+  case Qt::Key_Delete:
+    on_deleteButton_clicked();
+    break;
+  case Qt::Key_Return:
+  case Qt::Key_Enter:
+    on_treeView_clicked(ui->treeView->currentIndex());
+    break;
+  case Qt::Key_Escape:
+    ui->lineEdit->clear();
+    break;
+  default:
+    break;
+  }
+}
 
 void MainWindow::on_copyPasswordButton_clicked() { copyPasswordToClipboard(); }
 
@@ -1679,7 +1748,7 @@ void MainWindow::addFolder() {
   QString newdir = QInputDialog::getText(
       this, tr("New file"),
       tr("New Folder: \n(Will be placed in %1 )")
-      .arg(passStore + getDir(ui->treeView->currentIndex(), true)),
+          .arg(passStore + getDir(ui->treeView->currentIndex(), true)),
       QLineEdit::Normal, "", &ok);
   if (!ok || newdir.isEmpty())
     return;
@@ -1696,6 +1765,7 @@ void MainWindow::editPassword() {
   if (useGit && autoPull)
     on_updateButton_clicked();
   waitFor(30);
+  process->waitForFinished();
   // TODO(annejan) move to editbutton stuff possibly?
   currentDir = getDir(ui->treeView->currentIndex(), false);
   lastDecrypt = "Could not decrypt";
@@ -1708,7 +1778,7 @@ void MainWindow::editPassword() {
       executeWrapper(gpgExecutable,
                      "-d --quiet --yes --no-encrypt-to --batch --use-agent \"" +
                          file + '"');
-    process->waitForFinished(30000);  // long wait (passphrase stuff)
+    process->waitForFinished(30000); // long wait (passphrase stuff)
     if (process->exitStatus() == QProcess::NormalExit)
       on_editButton_clicked();
   }
@@ -1722,7 +1792,11 @@ QString MainWindow::generatePassword() {
   QString passwd;
   if (usePwgen) {
     waitFor(2);
-    QString args = (useSymbols ? "--symbols -1 " : "-1 ") +
+    // --secure goes first as it overrides --no-* otherwise
+    QString args = QString("-1 ") + (lessRandom ? "" : "--secure ") +
+                   (avoidCapitals ? "--no-capitalize " : "--capitalize ") +
+                   (avoidNumbers ? "--no-numerals " : "--numerals ") +
+                   (useSymbols ? "--symbols " : "") +
                    QString::number(passwordLength);
     currentAction = PWGEN;
     executeWrapper(pwgenExecutable, args);
@@ -1810,3 +1884,23 @@ void MainWindow::setClippedPassword(const QString &pass) {
 }
 
 const QString &MainWindow::getClippedPassword() { return clippedPass; }
+
+/**
+ * @brief MainWindow::reencryptPath reencrypt all files under the chosen directory
+ * @param dir
+ */
+void MainWindow::reencryptPath(QString dir) {
+    qDebug() << "reencrypt: " << dir;
+    // @TODO(annejan) disable interface until done
+    QDirIterator it(dir, QStringList() << "*.gpg", QDir::Files, QDirIterator::Subdirectories);
+    while (it.hasNext()) {
+        QString fileName = it.next();
+        qDebug() << fileName;
+    }
+
+    QMessageBox::information(
+        this, tr("Recursing not yet implemented!"),
+        tr("This is an issue that only happens when you are not using pass.\n"
+           "Passwords are not reencrypted in folder %1!").arg(dir));
+}
+
