@@ -2,23 +2,29 @@
 #define SINGLEAPPLICATION_H_
 
 #include <QApplication>
-#include <QSharedMemory>
 #include <QLocalServer>
+#include <QSharedMemory>
 
+/*!
+    \class SingleApplication
+    \brief The SingleApplication class is used for commandline intergration.
+
+    This class needs a bit of work or possibly replacement.
+ */
 class SingleApplication : public QApplication {
   Q_OBJECT
- public:
+public:
   SingleApplication(int &argc, char *argv[], const QString uniqueKey);
   bool isRunning();
   bool sendMessage(const QString &message);
 
- public slots:
+public slots:
   void receiveMessage();
 
- signals:
+signals:
   void messageAvailable(QString message);
 
- private:
+private:
   bool _isRunning;
   QString _uniqueKey;
   QSharedMemory sharedMemory;
@@ -27,4 +33,4 @@ class SingleApplication : public QApplication {
   static const int timeout = 1000;
 };
 
-#endif  // SINGLEAPPLICATION_H_
+#endif // SINGLEAPPLICATION_H_
