@@ -1,11 +1,11 @@
 #ifndef USERSDIALOG_H_
 #define USERSDIALOG_H_
 
+#include <QCloseEvent>
+#include <QDateTime>
 #include <QDialog>
 #include <QList>
 #include <QStandardItemModel>
-#include <QCloseEvent>
-#include <QDateTime>
 
 namespace Ui {
 class UsersDialog;
@@ -13,6 +13,10 @@ class UsersDialog;
 
 class QListWidgetItem;
 
+/*!
+    \struct UserInfo
+    \brief Stores key info lines including validity, creation date and more.
+ */
 struct UserInfo {
   UserInfo() : validity('-'), have_secret(false), enabled(false) {}
 
@@ -25,27 +29,35 @@ struct UserInfo {
   QDateTime created;
 };
 
+
+/*!
+    \class UsersDialog
+    \brief Handles listing and editing of GPG users.
+
+    Selection of whom to encrypt to.
+ */
 class UsersDialog : public QDialog {
   Q_OBJECT
 
- public:
+public:
   explicit UsersDialog(QWidget *parent = 0);
   ~UsersDialog();
   void setUsers(QList<UserInfo> *);
 
- protected:
+protected:
   void closeEvent(QCloseEvent *event);
+  void keyPressEvent(QKeyEvent *event);
 
- private slots:
+private slots:
   void itemChange(QListWidgetItem *item);
   void on_clearButton_clicked();
   void on_lineEdit_textChanged(const QString &filter);
   void on_checkBox_clicked();
 
- private:
+private:
   Ui::UsersDialog *ui;
   QList<UserInfo> *userList;
   void populateList(const QString &filter);
 };
 
-#endif  // USERSDIALOG_H_
+#endif // USERSDIALOG_H_
